@@ -22,3 +22,12 @@ expect_tensor_shape <- function(object, shape) {
   expect_tensor(object)
   expect_equal(object$shape, shape)
 }
+
+expect_recursive_equal <- function(x, y) {
+  if (is.list(x))
+    map2(x, y, expect_recursive_equal)
+  else if (inherits(x, "torch_tensor"))
+    expect_equal_to_tensor(x, y)
+  else
+    expect_equal(x, y)
+}
